Module country

Module country 

ISO 3166-1 alpha-2 country code validation.

Functions

country_code_valid
ISO 3166-1 alpha-2: two uppercase ASCII letters that are an officially assigned country code. Shape-only candidates such as XX/QZ/AA are rejected because they are not in the assigned set.